@@ -21,7 +21,7 @@ class Calibration(dict):
             self['T'] = 0
             self['gamma'] = 0
 
-    allowed_keys = ['T', 'gamma', 'theta', 'Tlim', 'phi', 'scale', 'scale_unit', 'absolute_phase', 'principal_point', 'area_tracks']
+    allowed_keys = ['T', 'gamma', 'theta', 'Tlim', 'phi', 'scale', 'scale_unit', 'absolute_phase', 'absolute_threeD', 'principal_point', 'area_tracks']
     def _allowed_key(key):
         if key in Calibration.allowed_keys:
             return 1
