@@ -32,7 +32,9 @@ def wave2_demodulation(s, T, gamma, wavelet):
     c = wl.cwt2(s, T, gamma, wavelet)
     if len(c.shape) == 4:
         c = c.reshape((gamma.size * T.size,) + shape)
-    ridge = np.argmax(np.abs(c), axis=0)
+    amplitude = np.abs(c)
+    ridge = np.argmax(amplitude, axis=0)
+    amplitude = amplitude[ridge, y, x]
     wrapped_phase = _possibly_masked(s, np.angle(c[ridge, y, x]))
 
     # plt.figure()
@@ -43,7 +45,7 @@ def wave2_demodulation(s, T, gamma, wavelet):
     # plt.show()
     # exit()
 
-    return wrapped_phase
+    return wrapped_phase, amplitude
 
 def wavelet2(s, T, gamma):
     """Helper function for phase demodulation of image using the morlet wavelet"""
@@ -64,7 +66,7 @@ def ft2(s, T, gamma):
     wrapped_phase = _possibly_masked(s, np.angle(lf_sync_freq))
     return wrapped_phase
 
-def demodulate(signal, calibration):
+def demodulate(signal, calibration, return_amplitude=False):
     """Function for demodulation using the Continuous Wavelet Transform method"""
     if len(signal.shape) == 2:
         Tstep = 1
@@ -79,7 +81,7 @@ def demodulate(signal, calibration):
             Trange = Trange[Trange >= 2]
         
         # threeD = isowavelet2(signal, Trange, calibration['gamma'])
-        wrapped_phase = wavelet2(signal, Trange, calibration['gamma'])
+        wrapped_phase, amplitude = wavelet2(signal, Trange, calibration['gamma'])
         unwrapped_phase = restoration.unwrap_phase(wrapped_phase)
 
         # plt.figure()
@@ -91,4 +93,7 @@ def demodulate(signal, calibration):
         # exit()
     else:
         raise ValueError('Signal must be a single channel')
-    return unwrapped_phase
+    if return_amplitude:
+        return unwrapped_phase, amplitude
+    else:
+        return unwrapped_phase
