@@ -198,7 +198,7 @@ def csv_to_3D(reconstructed_file, ext):
 
     export3D('{}.{}'.format(reconstructed_file_base, ext), {'grid': grid3d, 'texture': texture})
 
-def export3D(filename, reconstructions, out_3D_size=None, max_vertices=2**14, prefix=''):
+def export3D(filename, reconstructions, out_3D_size=None, max_vertices=max_vertices, prefix=''):
     """
     Function to export a 3D reconstruction with this package to a file
     Possible 3D formats are the same as for trimesh such as GL Transmission Format .glb
